"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GerritService = void 0;
const lodash_1 = __importDefault(require("lodash"));
const gerrit_api_1 = require("./gerrit.api");
class GerritService {
    constructor(inputs) {
        this.gerritApi = new gerrit_api_1.GerritApi(inputs);
        this.inputs = inputs;
    }
    async getPullRequestsWithCommits(repo, branch) {
        try {
            const prs = await this.gerritApi.getPullRequests(repo, branch);
            return Promise.all(prs.map(async (pr) => {
                const info = await this.gerritApi.getCommitsInfo(repo, pr);
                const result = {
                    ...info,
                    prDate: pr.updated || pr.created,
                    number: pr._number,
                    url: `${this.inputs.gerritHost}/c/${repo}/+/${pr._number}`,
                    title: pr.subject,
                };
                return result;
            }));
        }
        catch (error) {
            throw new Error(`failed to get pull requests: ${error.message}`);
        }
    }
    async getBranch(repo, branch) {
        try {
            const gerritBranch = await this.gerritApi.getBranch(repo, branch);
            return {
                name: branch,
                commit: gerritBranch.commit,
                commitMsg: gerritBranch.subject,
                commitURL: this.gerritApi.buildCommitUrl(repo, gerritBranch.commit),
                committerUsername: gerritBranch.committer.email || gerritBranch.committer.name
            };
        }
        catch (error) {
            if (lodash_1.default.get(error, 'response.statusCode') === 404) {
                return;
            }
            throw new Error(`failed to get branch: ${error.message}`);
        }
    }
}
exports.GerritService = GerritService;
//# sourceMappingURL=gerrit.bkp.service.js.map